summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/QtExtras/qmlstreamer/qmlstreamer.pro4
-rw-r--r--src/Runtime/Qt3DSRuntime/Qt3DSRuntime.pro1
-rw-r--r--src/Runtime/Runtime.pro3
-rw-r--r--src/Runtime/api/api.pro5
-rw-r--r--src/Runtime/api/studio3d/q3dscommandqueue.cpp (renamed from src/Viewer/studio3d/q3dscommandqueue.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dscommandqueue_p.h (renamed from src/Viewer/studio3d/q3dscommandqueue_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dsdatainput.cpp (renamed from src/Viewer/studio3d/q3dsdatainput.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dsdatainput.h (renamed from src/Viewer/studio3d/q3dsdatainput.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dsdatainput_p.h (renamed from src/Viewer/studio3d/q3dsdatainput_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dselement.cpp (renamed from src/Viewer/studio3d/q3dselement.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dselement.h (renamed from src/Viewer/studio3d/q3dselement.h)2
-rw-r--r--src/Runtime/api/studio3d/q3dselement_p.h (renamed from src/Viewer/studio3d/q3dselement_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dsimagesequencegenerator.cpp (renamed from src/Viewer/studio3d/q3dsimagesequencegenerator.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dsimagesequencegenerator_p.h (renamed from src/Viewer/studio3d/q3dsimagesequencegenerator_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dsimagesequencegeneratorthread.cpp (renamed from src/Viewer/studio3d/q3dsimagesequencegeneratorthread.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dsimagesequencegeneratorthread_p.h (renamed from src/Viewer/studio3d/q3dsimagesequencegeneratorthread_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dspresentation.cpp (renamed from src/Viewer/studio3d/q3dspresentation.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dspresentation.h (renamed from src/Viewer/studio3d/q3dspresentation.h)2
-rw-r--r--src/Runtime/api/studio3d/q3dspresentation_p.h (renamed from src/Viewer/studio3d/q3dspresentation_p.h)2
-rw-r--r--src/Runtime/api/studio3d/q3dssceneelement.cpp (renamed from src/Viewer/studio3d/q3dssceneelement.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dssceneelement.h (renamed from src/Viewer/studio3d/q3dssceneelement.h)2
-rw-r--r--src/Runtime/api/studio3d/q3dssceneelement_p.h (renamed from src/Viewer/studio3d/q3dssceneelement_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dssurfaceviewer.cpp (renamed from src/Viewer/studio3d/q3dssurfaceviewer.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dssurfaceviewer.h (renamed from src/Viewer/studio3d/q3dssurfaceviewer.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dssurfaceviewer_p.h (renamed from src/Viewer/studio3d/q3dssurfaceviewer_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dsviewersettings.cpp (renamed from src/Viewer/studio3d/q3dsviewersettings.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dsviewersettings.h (renamed from src/Viewer/studio3d/q3dsviewersettings.h)2
-rw-r--r--src/Runtime/api/studio3d/q3dsviewersettings_p.h (renamed from src/Viewer/studio3d/q3dsviewersettings_p.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dswidget.cpp (renamed from src/Viewer/studio3d/q3dswidget.cpp)0
-rw-r--r--src/Runtime/api/studio3d/q3dswidget.h (renamed from src/Viewer/studio3d/q3dswidget.h)0
-rw-r--r--src/Runtime/api/studio3d/q3dswidget_p.h (renamed from src/Viewer/studio3d/q3dswidget_p.h)0
-rw-r--r--src/Runtime/api/studio3d/qstudio3dglobal.h (renamed from src/Viewer/studio3d/qstudio3dglobal.h)0
-rw-r--r--src/Runtime/api/studio3d/studio3d.pro (renamed from src/Viewer/studio3d/studio3d.pri)21
-rw-r--r--src/Runtime/api/studio3d/studioutils.cpp (renamed from src/Viewer/studio3d/studioutils.cpp)0
-rw-r--r--src/Runtime/api/studio3d/studioutils_p.h (renamed from src/Viewer/studio3d/studioutils_p.h)0
-rw-r--r--src/Runtime/api/studio3d/viewerqmlstreamproxy.cpp (renamed from src/Viewer/studio3d/viewerqmlstreamproxy.cpp)0
-rw-r--r--src/Runtime/api/studio3d/viewerqmlstreamproxy_p.h (renamed from src/Viewer/studio3d/viewerqmlstreamproxy_p.h)0
-rw-r--r--src/Runtime/api/studio3dqml/q3dsplugin.cpp (renamed from src/Viewer/qmlviewer/Qt3DSViewPlugin.cpp)8
-rw-r--r--src/Runtime/api/studio3dqml/q3dsplugin.h (renamed from src/Viewer/qmlviewer/Qt3DSViewPlugin.h)10
-rw-r--r--src/Runtime/api/studio3dqml/q3dspresentationitem.cpp (renamed from src/Viewer/qmlviewer/q3dspresentationitem.cpp)0
-rw-r--r--src/Runtime/api/studio3dqml/q3dspresentationitem.h (renamed from src/Viewer/qmlviewer/q3dspresentationitem.h)2
-rw-r--r--src/Runtime/api/studio3dqml/q3dsrenderer.cpp (renamed from src/Viewer/qmlviewer/Qt3DSRenderer.cpp)10
-rw-r--r--src/Runtime/api/studio3dqml/q3dsrenderer.h (renamed from src/Viewer/qmlviewer/Qt3DSRenderer.h)2
-rw-r--r--src/Runtime/api/studio3dqml/q3dsstudio3d.cpp (renamed from src/Viewer/qmlviewer/Qt3DSView.cpp)62
-rw-r--r--src/Runtime/api/studio3dqml/q3dsstudio3d.h (renamed from src/Viewer/qmlviewer/Qt3DSView.h)13
-rw-r--r--src/Runtime/api/studio3dqml/qmldir (renamed from src/Viewer/qmlviewer/qmldir)2
-rw-r--r--src/Runtime/api/studio3dqml/studio3dqml.pro (renamed from src/Viewer/qmlviewer/qmlviewer.pro)14
-rw-r--r--src/Viewer/Qt3DViewer/Qt3DViewer.pro27
-rw-r--r--src/Viewer/Qt3DViewer/viewer.cpp4
-rw-r--r--src/Viewer/Qt3DViewer/viewer.h6
-rw-r--r--src/Viewer/Viewer.pro3
-rw-r--r--src/Viewer/studio3d/studio3d.pro20
-rw-r--r--sync.profile2
53 files changed, 115 insertions, 114 deletions
diff --git a/src/QtExtras/qmlstreamer/qmlstreamer.pro b/src/QtExtras/qmlstreamer/qmlstreamer.pro
index 39cd24f1..19b91a2b 100644
--- a/src/QtExtras/qmlstreamer/qmlstreamer.pro
+++ b/src/QtExtras/qmlstreamer/qmlstreamer.pro
@@ -43,8 +43,8 @@ HEADERS += \
q3dsqmlsubpresentationsettings.h
INCLUDEPATH += \
- $$PWD/../Runtime/Source/Engine/Include \
- $$PWD/../Runtime/Source/System/Include \
+ $$PWD/../Runtime/Source/engine \
+ $$PWD/../Runtime/Source/system \
$$PWD/../QtExtras/qmlstreamer
macos:QMAKE_LFLAGS_SONAME = -Wl,-install_name,@rpath/
diff --git a/src/Runtime/Qt3DSRuntime/Qt3DSRuntime.pro b/src/Runtime/Qt3DSRuntime/Qt3DSRuntime.pro
index ac5a3936..54aa0442 100644
--- a/src/Runtime/Qt3DSRuntime/Qt3DSRuntime.pro
+++ b/src/Runtime/Qt3DSRuntime/Qt3DSRuntime.pro
@@ -67,7 +67,6 @@ macos {
QMAKE_LFLAGS_SONAME = -Wl,-install_name,@rpath/
}
-
PREDEPS_LIBS = qt3dsruntimestatic
include(../../utils.pri)
diff --git a/src/Runtime/Runtime.pro b/src/Runtime/Runtime.pro
index abc3fe7b..aedfb1ee 100644
--- a/src/Runtime/Runtime.pro
+++ b/src/Runtime/Runtime.pro
@@ -2,7 +2,8 @@ TEMPLATE = subdirs
CONFIG += ordered
SUBDIRS += \
Qt3DSRuntimeStatic \
- Qt3DSRuntime
+ Qt3DSRuntime \
+ api
win32 {
SUBDIRS += \
diff --git a/src/Runtime/api/api.pro b/src/Runtime/api/api.pro
new file mode 100644
index 00000000..7d5b27d0
--- /dev/null
+++ b/src/Runtime/api/api.pro
@@ -0,0 +1,5 @@
+TEMPLATE = subdirs
+CONFIG += ordered
+SUBDIRS += \
+ studio3d \
+ studio3dqml
diff --git a/src/Viewer/studio3d/q3dscommandqueue.cpp b/src/Runtime/api/studio3d/q3dscommandqueue.cpp
index ed0ad8b5..ed0ad8b5 100644
--- a/src/Viewer/studio3d/q3dscommandqueue.cpp
+++ b/src/Runtime/api/studio3d/q3dscommandqueue.cpp
diff --git a/src/Viewer/studio3d/q3dscommandqueue_p.h b/src/Runtime/api/studio3d/q3dscommandqueue_p.h
index ff30829f..ff30829f 100644
--- a/src/Viewer/studio3d/q3dscommandqueue_p.h
+++ b/src/Runtime/api/studio3d/q3dscommandqueue_p.h
diff --git a/src/Viewer/studio3d/q3dsdatainput.cpp b/src/Runtime/api/studio3d/q3dsdatainput.cpp
index 3048613e..3048613e 100644
--- a/src/Viewer/studio3d/q3dsdatainput.cpp
+++ b/src/Runtime/api/studio3d/q3dsdatainput.cpp
diff --git a/src/Viewer/studio3d/q3dsdatainput.h b/src/Runtime/api/studio3d/q3dsdatainput.h
index fc5933fa..fc5933fa 100644
--- a/src/Viewer/studio3d/q3dsdatainput.h
+++ b/src/Runtime/api/studio3d/q3dsdatainput.h
diff --git a/src/Viewer/studio3d/q3dsdatainput_p.h b/src/Runtime/api/studio3d/q3dsdatainput_p.h
index 855406cd..855406cd 100644
--- a/src/Viewer/studio3d/q3dsdatainput_p.h
+++ b/src/Runtime/api/studio3d/q3dsdatainput_p.h
diff --git a/src/Viewer/studio3d/q3dselement.cpp b/src/Runtime/api/studio3d/q3dselement.cpp
index ac3221dd..ac3221dd 100644
--- a/src/Viewer/studio3d/q3dselement.cpp
+++ b/src/Runtime/api/studio3d/q3dselement.cpp
diff --git a/src/Viewer/studio3d/q3dselement.h b/src/Runtime/api/studio3d/q3dselement.h
index 6df5dde9..04c43f52 100644
--- a/src/Viewer/studio3d/q3dselement.h
+++ b/src/Runtime/api/studio3d/q3dselement.h
@@ -71,7 +71,7 @@ private:
Q_DISABLE_COPY(Q3DSElement)
friend class Q3DSPresentationPrivate;
- friend class Q3DSView;
+ friend class Q3DSStudio3D;
};
QT_END_NAMESPACE
diff --git a/src/Viewer/studio3d/q3dselement_p.h b/src/Runtime/api/studio3d/q3dselement_p.h
index d4e77b1c..d4e77b1c 100644
--- a/src/Viewer/studio3d/q3dselement_p.h
+++ b/src/Runtime/api/studio3d/q3dselement_p.h
diff --git a/src/Viewer/studio3d/q3dsimagesequencegenerator.cpp b/src/Runtime/api/studio3d/q3dsimagesequencegenerator.cpp
index d0b8251b..d0b8251b 100644
--- a/src/Viewer/studio3d/q3dsimagesequencegenerator.cpp
+++ b/src/Runtime/api/studio3d/q3dsimagesequencegenerator.cpp
diff --git a/src/Viewer/studio3d/q3dsimagesequencegenerator_p.h b/src/Runtime/api/studio3d/q3dsimagesequencegenerator_p.h
index bc56fb1e..bc56fb1e 100644
--- a/src/Viewer/studio3d/q3dsimagesequencegenerator_p.h
+++ b/src/Runtime/api/studio3d/q3dsimagesequencegenerator_p.h
diff --git a/src/Viewer/studio3d/q3dsimagesequencegeneratorthread.cpp b/src/Runtime/api/studio3d/q3dsimagesequencegeneratorthread.cpp
index 40bb95b9..40bb95b9 100644
--- a/src/Viewer/studio3d/q3dsimagesequencegeneratorthread.cpp
+++ b/src/Runtime/api/studio3d/q3dsimagesequencegeneratorthread.cpp
diff --git a/src/Viewer/studio3d/q3dsimagesequencegeneratorthread_p.h b/src/Runtime/api/studio3d/q3dsimagesequencegeneratorthread_p.h
index 45869a69..45869a69 100644
--- a/src/Viewer/studio3d/q3dsimagesequencegeneratorthread_p.h
+++ b/src/Runtime/api/studio3d/q3dsimagesequencegeneratorthread_p.h
diff --git a/src/Viewer/studio3d/q3dspresentation.cpp b/src/Runtime/api/studio3d/q3dspresentation.cpp
index 0887d702..0887d702 100644
--- a/src/Viewer/studio3d/q3dspresentation.cpp
+++ b/src/Runtime/api/studio3d/q3dspresentation.cpp
diff --git a/src/Viewer/studio3d/q3dspresentation.h b/src/Runtime/api/studio3d/q3dspresentation.h
index c0295e15..d7f02e49 100644
--- a/src/Viewer/studio3d/q3dspresentation.h
+++ b/src/Runtime/api/studio3d/q3dspresentation.h
@@ -124,7 +124,7 @@ private:
friend class Q3DSSurfaceViewerPrivate;
friend class Q3DSWidgetPrivate;
friend class Q3DSRenderer;
- friend class Q3DSView;
+ friend class Q3DSStudio3D;
friend class Q3DSDataInput;
};
diff --git a/src/Viewer/studio3d/q3dspresentation_p.h b/src/Runtime/api/studio3d/q3dspresentation_p.h
index c82e27a7..6172aa33 100644
--- a/src/Viewer/studio3d/q3dspresentation_p.h
+++ b/src/Runtime/api/studio3d/q3dspresentation_p.h
@@ -103,6 +103,8 @@ private:
QStringList m_variantList;
ViewerQmlStreamProxy *m_streamProxy;
bool m_delayedLoading;
+
+ friend class Q3DSStudio3D;
};
QT_END_NAMESPACE
diff --git a/src/Viewer/studio3d/q3dssceneelement.cpp b/src/Runtime/api/studio3d/q3dssceneelement.cpp
index 2eef5d00..2eef5d00 100644
--- a/src/Viewer/studio3d/q3dssceneelement.cpp
+++ b/src/Runtime/api/studio3d/q3dssceneelement.cpp
diff --git a/src/Viewer/studio3d/q3dssceneelement.h b/src/Runtime/api/studio3d/q3dssceneelement.h
index 0eb7a972..2d96255c 100644
--- a/src/Viewer/studio3d/q3dssceneelement.h
+++ b/src/Runtime/api/studio3d/q3dssceneelement.h
@@ -75,7 +75,7 @@ private:
Q_DISABLE_COPY(Q3DSSceneElement)
friend class Q3DSPresentationPrivate;
- friend class Q3DSView;
+ friend class Q3DSStudio3D;
};
QT_END_NAMESPACE
diff --git a/src/Viewer/studio3d/q3dssceneelement_p.h b/src/Runtime/api/studio3d/q3dssceneelement_p.h
index 02d2bdff..02d2bdff 100644
--- a/src/Viewer/studio3d/q3dssceneelement_p.h
+++ b/src/Runtime/api/studio3d/q3dssceneelement_p.h
diff --git a/src/Viewer/studio3d/q3dssurfaceviewer.cpp b/src/Runtime/api/studio3d/q3dssurfaceviewer.cpp
index fc90e341..fc90e341 100644
--- a/src/Viewer/studio3d/q3dssurfaceviewer.cpp
+++ b/src/Runtime/api/studio3d/q3dssurfaceviewer.cpp
diff --git a/src/Viewer/studio3d/q3dssurfaceviewer.h b/src/Runtime/api/studio3d/q3dssurfaceviewer.h
index 90d25aa1..90d25aa1 100644
--- a/src/Viewer/studio3d/q3dssurfaceviewer.h
+++ b/src/Runtime/api/studio3d/q3dssurfaceviewer.h
diff --git a/src/Viewer/studio3d/q3dssurfaceviewer_p.h b/src/Runtime/api/studio3d/q3dssurfaceviewer_p.h
index 9c56c1b5..9c56c1b5 100644
--- a/src/Viewer/studio3d/q3dssurfaceviewer_p.h
+++ b/src/Runtime/api/studio3d/q3dssurfaceviewer_p.h
diff --git a/src/Viewer/studio3d/q3dsviewersettings.cpp b/src/Runtime/api/studio3d/q3dsviewersettings.cpp
index b6660c84..b6660c84 100644
--- a/src/Viewer/studio3d/q3dsviewersettings.cpp
+++ b/src/Runtime/api/studio3d/q3dsviewersettings.cpp
diff --git a/src/Viewer/studio3d/q3dsviewersettings.h b/src/Runtime/api/studio3d/q3dsviewersettings.h
index 312107a3..82d7d62e 100644
--- a/src/Viewer/studio3d/q3dsviewersettings.h
+++ b/src/Runtime/api/studio3d/q3dsviewersettings.h
@@ -93,7 +93,7 @@ private:
friend class Q3DSSurfaceViewerPrivate;
friend class Q3DSWidgetPrivate;
friend class Q3DSRenderer;
- friend class Q3DSView;
+ friend class Q3DSStudio3D;
};
QT_END_NAMESPACE
diff --git a/src/Viewer/studio3d/q3dsviewersettings_p.h b/src/Runtime/api/studio3d/q3dsviewersettings_p.h
index 48fbae3a..48fbae3a 100644
--- a/src/Viewer/studio3d/q3dsviewersettings_p.h
+++ b/src/Runtime/api/studio3d/q3dsviewersettings_p.h
diff --git a/src/Viewer/studio3d/q3dswidget.cpp b/src/Runtime/api/studio3d/q3dswidget.cpp
index 23334b5b..23334b5b 100644
--- a/src/Viewer/studio3d/q3dswidget.cpp
+++ b/src/Runtime/api/studio3d/q3dswidget.cpp
diff --git a/src/Viewer/studio3d/q3dswidget.h b/src/Runtime/api/studio3d/q3dswidget.h
index ad5d823d..ad5d823d 100644
--- a/src/Viewer/studio3d/q3dswidget.h
+++ b/src/Runtime/api/studio3d/q3dswidget.h
diff --git a/src/Viewer/studio3d/q3dswidget_p.h b/src/Runtime/api/studio3d/q3dswidget_p.h
index 03ca6aac..03ca6aac 100644
--- a/src/Viewer/studio3d/q3dswidget_p.h
+++ b/src/Runtime/api/studio3d/q3dswidget_p.h
diff --git a/src/Viewer/studio3d/qstudio3dglobal.h b/src/Runtime/api/studio3d/qstudio3dglobal.h
index d1960634..d1960634 100644
--- a/src/Viewer/studio3d/qstudio3dglobal.h
+++ b/src/Runtime/api/studio3d/qstudio3dglobal.h
diff --git a/src/Viewer/studio3d/studio3d.pri b/src/Runtime/api/studio3d/studio3d.pro
index 36ad503a..6c5e0585 100644
--- a/src/Viewer/studio3d/studio3d.pri
+++ b/src/Runtime/api/studio3d/studio3d.pro
@@ -1,3 +1,18 @@
+TARGET = QtStudio3D
+
+include($$PWD/../../commoninclude.pri)
+QT += opengl widgets qml
+
+qtHaveModule(multimedia) {
+DEFINES += PLATFORM_HAS_QT_MULTIMEDIA_LIB
+QT += multimedia
+}
+CONFIG += console
+
+LIBS += \
+ -lqt3dsopengl$$qtPlatformTargetSuffix() \
+ -lqt3dsqmlstreamer$$qtPlatformTargetSuffix()
+
HEADERS += \
q3dswidget.h \
q3dswidget_p.h \
@@ -33,6 +48,6 @@ SOURCES += q3dswidget.cpp \
q3dsimagesequencegeneratorthread.cpp \
q3dsdatainput.cpp
-macos {
-INCLUDEPATH += $$PWD/../../Runtime/SDKsAndTools/nvap_sdk/libs/inc
-}
+load(qt_module)
+
+OTHER_FILES += $$PWD/../../../doc/src/12-cpp-reference/*
diff --git a/src/Viewer/studio3d/studioutils.cpp b/src/Runtime/api/studio3d/studioutils.cpp
index 9156be7f..9156be7f 100644
--- a/src/Viewer/studio3d/studioutils.cpp
+++ b/src/Runtime/api/studio3d/studioutils.cpp
diff --git a/src/Viewer/studio3d/studioutils_p.h b/src/Runtime/api/studio3d/studioutils_p.h
index afec688c..afec688c 100644
--- a/src/Viewer/studio3d/studioutils_p.h
+++ b/src/Runtime/api/studio3d/studioutils_p.h
diff --git a/src/Viewer/studio3d/viewerqmlstreamproxy.cpp b/src/Runtime/api/studio3d/viewerqmlstreamproxy.cpp
index 520dc8c6..520dc8c6 100644
--- a/src/Viewer/studio3d/viewerqmlstreamproxy.cpp
+++ b/src/Runtime/api/studio3d/viewerqmlstreamproxy.cpp
diff --git a/src/Viewer/studio3d/viewerqmlstreamproxy_p.h b/src/Runtime/api/studio3d/viewerqmlstreamproxy_p.h
index 16569c1c..16569c1c 100644
--- a/src/Viewer/studio3d/viewerqmlstreamproxy_p.h
+++ b/src/Runtime/api/studio3d/viewerqmlstreamproxy_p.h
diff --git a/src/Viewer/qmlviewer/Qt3DSViewPlugin.cpp b/src/Runtime/api/studio3dqml/q3dsplugin.cpp
index d91581e7..aa558775 100644
--- a/src/Viewer/qmlviewer/Qt3DSViewPlugin.cpp
+++ b/src/Runtime/api/studio3dqml/q3dsplugin.cpp
@@ -28,13 +28,13 @@
**
****************************************************************************/
-#include "Qt3DSViewPlugin.h"
+#include "q3dsplugin.h"
#include <QtQml/qqml.h>
#include <QtStudio3D/private/q3dsviewersettings_p.h>
-#include "Qt3DSView.h"
+#include "q3dsstudio3d.h"
#include "q3dspresentationitem.h"
#include "q3dsqmlstream.h"
#include "q3dsqmlsubpresentationsettings.h"
@@ -43,12 +43,12 @@
QT_BEGIN_NAMESPACE
-void Q3DSViewPlugin::registerTypes(const char *uri)
+void Q3DSPlugin::registerTypes(const char *uri)
{
Q_ASSERT(uri == QLatin1String("QtStudio3D.OpenGL"));
// @uri QtStudio3D.OpenGL
- qmlRegisterType<Q3DSView>(uri, 2, 4, "Studio3D");
+ qmlRegisterType<Q3DSStudio3D>(uri, 2, 4, "Studio3D");
qmlRegisterType<Q3DSViewerSettings>(uri, 2, 4, "ViewerSettings");
qmlRegisterType<Q3DSPresentationItem>(uri, 2, 4, "Presentation");
qmlRegisterType<Q3DSSceneElement>(uri, 2, 4, "SceneElement");
diff --git a/src/Viewer/qmlviewer/Qt3DSViewPlugin.h b/src/Runtime/api/studio3dqml/q3dsplugin.h
index 1d1a6fff..999a0659 100644
--- a/src/Viewer/qmlviewer/Qt3DSViewPlugin.h
+++ b/src/Runtime/api/studio3dqml/q3dsplugin.h
@@ -28,8 +28,8 @@
**
****************************************************************************/
-#ifndef Q3DSVIEW_PLUGIN_H
-#define Q3DSVIEW_PLUGIN_H
+#ifndef Q3DS_PLUGIN_H
+#define Q3DS_PLUGIN_H
#include <QtQml/qqmlextensionplugin.h>
@@ -42,13 +42,13 @@ static void initResources()
QT_BEGIN_NAMESPACE
-class Q3DSViewPlugin : public QQmlExtensionPlugin
+class Q3DSPlugin : public QQmlExtensionPlugin
{
Q_OBJECT
Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
public:
- Q3DSViewPlugin(QObject *parent = 0) : QQmlExtensionPlugin(parent)
+ Q3DSPlugin(QObject *parent = 0) : QQmlExtensionPlugin(parent)
{
initResources();
}
@@ -57,4 +57,4 @@ public:
QT_END_NAMESPACE
-#endif // Q3DSVIEW_PLUGIN_H
+#endif // Q3DS_PLUGIN_H
diff --git a/src/Viewer/qmlviewer/q3dspresentationitem.cpp b/src/Runtime/api/studio3dqml/q3dspresentationitem.cpp
index 6c4c8e36..6c4c8e36 100644
--- a/src/Viewer/qmlviewer/q3dspresentationitem.cpp
+++ b/src/Runtime/api/studio3dqml/q3dspresentationitem.cpp
diff --git a/src/Viewer/qmlviewer/q3dspresentationitem.h b/src/Runtime/api/studio3dqml/q3dspresentationitem.h
index 63270594..3ee2964f 100644
--- a/src/Viewer/qmlviewer/q3dspresentationitem.h
+++ b/src/Runtime/api/studio3dqml/q3dspresentationitem.h
@@ -57,6 +57,8 @@ public Q_SLOTS:
private:
Q3DSSubPresentationSettings *m_subPresentationSettings;
+
+ friend class Q3DSStudio3D;
};
QT_END_NAMESPACE
diff --git a/src/Viewer/qmlviewer/Qt3DSRenderer.h b/src/Runtime/api/studio3dqml/q3dsrenderer.h
index 59d9d972..12f98aef 100644
--- a/src/Viewer/qmlviewer/Qt3DSRenderer.h
+++ b/src/Runtime/api/studio3dqml/q3dsrenderer.h
@@ -35,7 +35,7 @@
#include <QtQuick/qquickframebufferobject.h>
#include "Qt3DSViewerApp.h"
-#include "Qt3DSView.h"
+#include "q3dsstudio3d.h"
QT_BEGIN_NAMESPACE
diff --git a/src/Viewer/qmlviewer/Qt3DSView.cpp b/src/Runtime/api/studio3dqml/q3dsstudio3d.cpp
index bf54b6da..2a6c7be2 100644
--- a/src/Viewer/qmlviewer/Qt3DSView.cpp
+++ b/src/Runtime/api/studio3dqml/q3dsstudio3d.cpp
@@ -28,8 +28,8 @@
**
****************************************************************************/
-#include "Qt3DSView.h"
-#include "Qt3DSRenderer.h"
+#include "q3dsstudio3d.h"
+#include "q3dsrenderer.h"
#include "q3dspresentationitem.h"
#include <QtStudio3D/private/q3dsviewersettings_p.h>
@@ -43,7 +43,7 @@
QT_BEGIN_NAMESPACE
-Q3DSView::Q3DSView()
+Q3DSStudio3D::Q3DSStudio3D()
: m_viewerSettings(nullptr)
, m_presentation(nullptr)
, m_emitRunningChange(false)
@@ -54,32 +54,32 @@ Q3DSView::Q3DSView()
, m_pixelRatio(1.0)
{
setMirrorVertically(true);
- connect(this, &Q3DSView::windowChanged, this, &Q3DSView::handleWindowChanged);
- connect(this, &Q3DSView::visibleChanged, this, &Q3DSView::handleVisibleChanged);
+ connect(this, &Q3DSStudio3D::windowChanged, this, &Q3DSStudio3D::handleWindowChanged);
+ connect(this, &Q3DSStudio3D::visibleChanged, this, &Q3DSStudio3D::handleVisibleChanged);
setIgnoreEvents(false, false, false);
}
-Q3DSView::~Q3DSView()
+Q3DSStudio3D::~Q3DSStudio3D()
{
}
-Q3DSPresentationItem *Q3DSView::presentation() const
+Q3DSPresentationItem *Q3DSStudio3D::presentation() const
{
return m_presentation;
}
-Q3DSViewerSettings *Q3DSView::viewerSettings() const
+Q3DSViewerSettings *Q3DSStudio3D::viewerSettings() const
{
return m_viewerSettings;
}
-QString Q3DSView::error() const
+QString Q3DSStudio3D::error() const
{
return m_error;
}
-void Q3DSView::setError(const QString &error)
+void Q3DSStudio3D::setError(const QString &error)
{
if (error != m_error) {
m_error = error;
@@ -87,7 +87,7 @@ void Q3DSView::setError(const QString &error)
}
}
-void Q3DSView::setIgnoreEvents(bool mouse, bool wheel, bool keyboard)
+void Q3DSStudio3D::setIgnoreEvents(bool mouse, bool wheel, bool keyboard)
{
// TODO: It might be beneficial to have these as properties so they could be acceessed from QML
m_ignoreMouseEvents = mouse;
@@ -101,7 +101,7 @@ void Q3DSView::setIgnoreEvents(bool mouse, bool wheel, bool keyboard)
setAcceptHoverEvents(!mouse);
}
-void Q3DSView::componentComplete()
+void Q3DSStudio3D::componentComplete()
{
const auto childObjs = children();
for (QObject *child : childObjs) {
@@ -134,7 +134,7 @@ void Q3DSView::componentComplete()
QQuickFramebufferObject::componentComplete();
}
-void Q3DSView::handleWindowChanged(QQuickWindow *window)
+void Q3DSStudio3D::handleWindowChanged(QQuickWindow *window)
{
if (!window)
return;
@@ -143,19 +143,19 @@ void Q3DSView::handleWindowChanged(QQuickWindow *window)
m_pixelRatio = window->devicePixelRatio();
// Call tick every frame of the GUI thread to notify QML about new frame via frameUpdate signal
- connect(window, &QQuickWindow::afterAnimating, this, &Q3DSView::tick);
+ connect(window, &QQuickWindow::afterAnimating, this, &Q3DSStudio3D::tick);
// Call update after the frame is handled to queue another frame
- connect(window, &QQuickWindow::afterSynchronizing, this, &Q3DSView::update);
+ connect(window, &QQuickWindow::afterSynchronizing, this, &Q3DSStudio3D::update);
}
// Queue up a command to inform the renderer of a newly-changed visible/hidden status.
-void Q3DSView::handleVisibleChanged()
+void Q3DSStudio3D::handleVisibleChanged()
{
m_pendingCommands.m_visibleChanged = true;
m_pendingCommands.m_visible = isVisible();
}
-void Q3DSView::reset()
+void Q3DSStudio3D::reset()
{
// Fake a source change to trigger a reloading of the presentation
m_pendingCommands.m_sourceChanged = true;
@@ -164,7 +164,7 @@ void Q3DSView::reset()
m_pendingCommands.m_variantList = m_presentation->variantList();
}
-void Q3DSView::requestResponseHandler(const QString &elementPath, CommandType commandType,
+void Q3DSStudio3D::requestResponseHandler(const QString &elementPath, CommandType commandType,
void *requestData)
{
switch (commandType) {
@@ -194,7 +194,7 @@ void Q3DSView::requestResponseHandler(const QString &elementPath, CommandType co
}
// Create the Q3DSRenderer. Invoked automatically by the QML scene graph.
-QQuickFramebufferObject::Renderer *Q3DSView::createRenderer() const
+QQuickFramebufferObject::Renderer *Q3DSStudio3D::createRenderer() const
{
// It is "illegal" to create a connection between the renderer
// and the plugin, and vice-versa. The only valid time the two
@@ -212,15 +212,15 @@ QQuickFramebufferObject::Renderer *Q3DSView::createRenderer() const
connect(renderer, &Q3DSRenderer::materialCreated,
m_presentation, &Q3DSPresentation::materialCreated);
connect(renderer, &Q3DSRenderer::requestResponse,
- this, &Q3DSView::requestResponseHandler);
+ this, &Q3DSStudio3D::requestResponseHandler);
connect(renderer, &Q3DSRenderer::presentationLoaded,
- this, &Q3DSView::presentationLoaded);
+ this, &Q3DSStudio3D::presentationLoaded);
connect(renderer, &Q3DSRenderer::presentationReady,
- this, &Q3DSView::presentationReady);
+ this, &Q3DSStudio3D::presentationReady);
return renderer;
}
-bool Q3DSView::isRunning() const
+bool Q3DSStudio3D::isRunning() const
{
return m_isRunning;
}
@@ -238,7 +238,7 @@ bool Q3DSView::isRunning() const
* ...
* }
*/
-void Q3DSView::tick()
+void Q3DSStudio3D::tick()
{
if (m_emitRunningChange) {
m_isRunning = true;
@@ -254,7 +254,7 @@ void Q3DSView::tick()
}
// Copies the list of commands previously queued up. Called by Q3DSRenderer::synchronize().
-void Q3DSView::getCommands(bool emitInitialize, CommandQueue &renderQueue)
+void Q3DSStudio3D::getCommands(bool emitInitialize, CommandQueue &renderQueue)
{
if (emitInitialize)
m_emitRunningChange = true;
@@ -263,7 +263,7 @@ void Q3DSView::getCommands(bool emitInitialize, CommandQueue &renderQueue)
m_pendingCommands.clear(false);
}
-void Q3DSView::mousePressEvent(QMouseEvent *event)
+void Q3DSStudio3D::mousePressEvent(QMouseEvent *event)
{
if (!m_ignoreMouseEvents) {
if (m_pixelRatio != 1.0) {
@@ -276,7 +276,7 @@ void Q3DSView::mousePressEvent(QMouseEvent *event)
}
}
-void Q3DSView::mouseReleaseEvent(QMouseEvent *event)
+void Q3DSStudio3D::mouseReleaseEvent(QMouseEvent *event)
{
if (!m_ignoreMouseEvents) {
if (m_pixelRatio != 1.0) {
@@ -289,7 +289,7 @@ void Q3DSView::mouseReleaseEvent(QMouseEvent *event)
}
}
-void Q3DSView::mouseMoveEvent(QMouseEvent *event)
+void Q3DSStudio3D::mouseMoveEvent(QMouseEvent *event)
{
if (!m_ignoreMouseEvents) {
if (m_pixelRatio != 1.0) {
@@ -302,20 +302,20 @@ void Q3DSView::mouseMoveEvent(QMouseEvent *event)
}
}
-void Q3DSView::wheelEvent(QWheelEvent *event)
+void Q3DSStudio3D::wheelEvent(QWheelEvent *event)
{
if (!m_ignoreWheelEvents)
m_presentation->wheelEvent(event);
}
-void Q3DSView::keyPressEvent(QKeyEvent *event)
+void Q3DSStudio3D::keyPressEvent(QKeyEvent *event)
{
if (m_ignoreKeyboardEvents)
return;
m_presentation->keyPressEvent(event);
}
-void Q3DSView::keyReleaseEvent(QKeyEvent *event)
+void Q3DSStudio3D::keyReleaseEvent(QKeyEvent *event)
{
if (m_ignoreKeyboardEvents)
return;
diff --git a/src/Viewer/qmlviewer/Qt3DSView.h b/src/Runtime/api/studio3dqml/q3dsstudio3d.h
index 0a4e67d8..484e9f65 100644
--- a/src/Viewer/qmlviewer/Qt3DSView.h
+++ b/src/Runtime/api/studio3dqml/q3dsstudio3d.h
@@ -28,9 +28,8 @@
**
****************************************************************************/
-#ifndef Q3DS_VIEW_H
-#define Q3DS_VIEW_H
-
+#ifndef Q3DS_STUDIO3D_H
+#define Q3DS_STUDIO3D_H
#include <QtStudio3D/private/q3dscommandqueue_p.h>
#include <QtGui/qopenglframebufferobject.h>
@@ -42,7 +41,7 @@ class Q3DSRenderer;
class Q3DSViewerSettings;
class Q3DSPresentationItem;
-class Q3DSView : public QQuickFramebufferObject
+class Q3DSStudio3D : public QQuickFramebufferObject
{
Q_OBJECT
Q_PROPERTY(bool running READ isRunning NOTIFY runningChanged)
@@ -51,8 +50,8 @@ class Q3DSView : public QQuickFramebufferObject
Q_PROPERTY(QString error READ error NOTIFY errorChanged)
public:
- Q3DSView();
- virtual ~Q3DSView();
+ Q3DSStudio3D();
+ virtual ~Q3DSStudio3D();
QQuickFramebufferObject::Renderer *createRenderer() const override;
@@ -109,4 +108,4 @@ protected:
QT_END_NAMESPACE
-#endif // Q3DS_VIEW_H
+#endif // Q3DS_STUDIO3D_H
diff --git a/src/Viewer/qmlviewer/qmldir b/src/Runtime/api/studio3dqml/qmldir
index a6ecc699..1eaa8f2b 100644
--- a/src/Viewer/qmlviewer/qmldir
+++ b/src/Runtime/api/studio3dqml/qmldir
@@ -1,3 +1,3 @@
module QtStudio3D.OpenGL
plugin declarative_qtstudio3dopengl
-classname Q3DSViewPlugin
+classname Q3DSPlugin
diff --git a/src/Viewer/qmlviewer/qmlviewer.pro b/src/Runtime/api/studio3dqml/studio3dqml.pro
index 7fe3dd20..a7bdc392 100644
--- a/src/Viewer/qmlviewer/qmlviewer.pro
+++ b/src/Runtime/api/studio3dqml/studio3dqml.pro
@@ -1,4 +1,4 @@
-include($$PWD/../../Runtime/commoninclude.pri)
+include($$PWD/../../commoninclude.pri)
QT += qml quick opengl studio3d-private
CONFIG += plugin
@@ -13,15 +13,15 @@ TARGETPATH = QtStudio3D/OpenGL
IMPORT_VERSION = 2.4
SOURCES += \
- Qt3DSViewPlugin.cpp \
- Qt3DSView.cpp \
- Qt3DSRenderer.cpp \
+ q3dsplugin.cpp \
+ q3dsstudio3d.cpp \
+ q3dsrenderer.cpp \
q3dspresentationitem.cpp
HEADERS += \
- Qt3DSViewPlugin.h \
- Qt3DSView.h \
- Qt3DSRenderer.h \
+ q3dsplugin.h \
+ q3dsstudio3d.h \
+ q3dsrenderer.h \
q3dspresentationitem.h
LIBS += \
diff --git a/src/Viewer/Qt3DViewer/Qt3DViewer.pro b/src/Viewer/Qt3DViewer/Qt3DViewer.pro
index 86e05dde..65c4d972 100644
--- a/src/Viewer/Qt3DViewer/Qt3DViewer.pro
+++ b/src/Viewer/Qt3DViewer/Qt3DViewer.pro
@@ -4,7 +4,8 @@ TEMPLATE = app
TARGET = Qt3DViewer
QT += qml quickcontrols2 studio3d-private
-INCLUDEPATH += $$PWD/../qmlviewer
+INCLUDEPATH += $$PWD/../../Runtime/api/studio3dqml
+INCLUDEPATH += $$PWD/../../Runtime/api/studio3d
RESOURCES += Viewer.qrc
RC_ICONS = resources/images/3D-studio-viewer.ico
@@ -12,30 +13,30 @@ RC_ICONS = resources/images/3D-studio-viewer.ico
ICON = resources/images/viewer.icns
SOURCES += \
- $$PWD/../qmlviewer/Qt3DSView.cpp \
- $$PWD/../qmlviewer/Qt3DSRenderer.cpp \
- $$PWD/../qmlviewer/q3dspresentationitem.cpp \
+ $$PWD/../../Runtime/api/studio3dqml/q3dsstudio3d.cpp \
+ $$PWD/../../Runtime/api/studio3dqml/q3dsrenderer.cpp \
+ $$PWD/../../Runtime/api/studio3dqml/q3dspresentationitem.cpp \
main.cpp \
viewer.cpp \
remotedeploymentreceiver.cpp
HEADERS += \
- $$PWD/../qmlviewer/Qt3DSView.h \
- $$PWD/../qmlviewer/Qt3DSRenderer.h \
- $$PWD/../qmlviewer/q3dspresentationitem.h \
+ $$PWD/../../Runtime/api/studio3dqml/q3dsstudio3d.h \
+ $$PWD/../../Runtime/api/studio3dqml/q3dsrenderer.h \
+ $$PWD/../../Runtime/api/studio3dqml/q3dspresentationitem.h \
viewer.h \
remotedeploymentreceiver.h
android: {
SOURCES += \
- $$PWD/../studio3d/q3dsviewersettings.cpp \
- $$PWD/../studio3d/q3dspresentation.cpp \
- $$PWD/../studio3d/q3dsdatainput.cpp
+ $$PWD/../../Runtime/api/studio3d/q3dsviewersettings.cpp \
+ $$PWD/../../Runtime/api/studio3d/q3dspresentation.cpp \
+ $$PWD/../../Runtime/api/studio3d/q3dsdatainput.cpp
HEADERS += \
- $$PWD/../studio3d/q3dsviewersettings.h \
- $$PWD/../studio3d/q3dspresentation.h \
- $$PWD/../studio3d/q3dsdatainput.h
+ $$PWD/../../Runtime/api/studio3d/q3dsviewersettings.h \
+ $$PWD/../../Runtime/api/studio3d/q3dspresentation.h \
+ $$PWD/../../Runtime/api/studio3d/q3dsdatainput.h
}
LIBS += \
diff --git a/src/Viewer/Qt3DViewer/viewer.cpp b/src/Viewer/Qt3DViewer/viewer.cpp
index 2a32cb76..b6ce05b7 100644
--- a/src/Viewer/Qt3DViewer/viewer.cpp
+++ b/src/Viewer/Qt3DViewer/viewer.cpp
@@ -356,12 +356,12 @@ void Viewer::resetConnectionInfoText()
Q_EMIT connectTextChanged();
}
-Q3DSView *Viewer::qmlStudio()
+Q3DSStudio3D *Viewer::qmlStudio()
{
if (m_contentView == StudioView) {
if (!m_qmlStudio) {
QObject *loadedContent = m_qmlRootObject->property("loadedContent").value<QObject *>();
- m_qmlStudio = static_cast<Q3DSView *>(loadedContent);
+ m_qmlStudio = static_cast<Q3DSStudio3D *>(loadedContent);
}
} else {
m_qmlStudio = nullptr;
diff --git a/src/Viewer/Qt3DViewer/viewer.h b/src/Viewer/Qt3DViewer/viewer.h
index 989481b9..cff7a23c 100644
--- a/src/Viewer/Qt3DViewer/viewer.h
+++ b/src/Viewer/Qt3DViewer/viewer.h
@@ -36,7 +36,7 @@
#include <QtCore/qurl.h>
#include <QtCore/qtimer.h>
#include <QtGui/qwindow.h>
-#include "Qt3DSView.h"
+#include "q3dsstudio3d.h"
class Viewer : public QObject
{
@@ -111,7 +111,7 @@ Q_SIGNALS:
void showInfoOverlay(const QString &infoStr);
private:
- Q3DSView *qmlStudio();
+ Q3DSStudio3D *qmlStudio();
QString m_openFileDir;
QStringList m_variantList;
@@ -121,7 +121,7 @@ private:
QObject *m_qmlRootObject = nullptr;
int m_connectPort = -1;
QString m_connectText;
- Q3DSView *m_qmlStudio = nullptr;
+ Q3DSStudio3D *m_qmlStudio = nullptr;
QTimer m_connectTextResetTimer;
};
diff --git a/src/Viewer/Viewer.pro b/src/Viewer/Viewer.pro
index 07bdb7ad..736f0dc3 100644
--- a/src/Viewer/Viewer.pro
+++ b/src/Viewer/Viewer.pro
@@ -1,8 +1,5 @@
TEMPLATE = subdirs
CONFIG += ordered
-SUBDIRS += \
- studio3d \
- qmlviewer
!boot2qt:!integrity:!qnx {
SUBDIRS += Qt3DViewer
diff --git a/src/Viewer/studio3d/studio3d.pro b/src/Viewer/studio3d/studio3d.pro
deleted file mode 100644
index 8fee4003..00000000
--- a/src/Viewer/studio3d/studio3d.pro
+++ /dev/null
@@ -1,20 +0,0 @@
-TARGET = QtStudio3D
-
-include($$PWD/../../Runtime/commoninclude.pri)
-QT += opengl widgets qml
-
-qtHaveModule(multimedia) {
-DEFINES += PLATFORM_HAS_QT_MULTIMEDIA_LIB
-QT += multimedia
-}
-CONFIG += console
-
-LIBS += \
- -lqt3dsopengl$$qtPlatformTargetSuffix() \
- -lqt3dsqmlstreamer$$qtPlatformTargetSuffix()
-
-include(studio3d.pri)
-
-load(qt_module)
-
-OTHER_FILES += $$PWD/../../../doc/src/12-cpp-reference/*
diff --git a/sync.profile b/sync.profile
index aa354125..f58c0325 100644
--- a/sync.profile
+++ b/sync.profile
@@ -1,5 +1,5 @@
%modules = ( # path to module name map
- "QtStudio3D" => "$basedir/src/Viewer/studio3d",
+ "QtStudio3D" => "$basedir/src/Runtime/api/studio3d",
);
%moduleheaders = ( # restrict the module headers to those found in relative path
);
diff --git a/src/Viewer/qmlviewer/Qt3DSRenderer.cpp b/src/Runtime/api/studio3dqml/q3dsrenderer.cpp
index d1274d7d..7e063ab4 100644
--- a/src/Viewer/qmlviewer/Qt3DSRenderer.cpp
+++ b/src/Runtime/api/studio3dqml/q3dsrenderer.cpp
@@ -28,7 +28,7 @@
**
****************************************************************************/
-#include "Qt3DSRenderer.h"
+#include "q3dsrenderer.h"
#include "Qt3DSViewerApp.h"
#include "Qt3DSAudioPlayerImpl.h"
#include "q3dspresentationitem.h"
@@ -80,15 +80,15 @@ QOpenGLFramebufferObject *Q3DSRenderer::createFramebufferObject(const QSize &siz
/** Pull pending commands from the plugin.
* Invoked automatically by the QML scene graph.
*
* This is the only place where it is valid for the Q3DSView plugin and render to communicate.
*/
void Q3DSRenderer::synchronize(QQuickFramebufferObject *inView)
{
// Passing m_InitElements here is a bit of a hack to easily set the flag on the plugin.
- static_cast<Q3DSView *>(inView)->getCommands(m_initElements, m_commands);
+ static_cast<Q3DSStudio3D *>(inView)->getCommands(m_initElements, m_commands);
if (m_initializationFailure)
- static_cast<Q3DSView *>(inView)->setError(m_error);
+ static_cast<Q3DSStudio3D *>(inView)->setError(m_error);
if (m_commands.m_sourceChanged || m_commands.m_variantListChanged) {
releaseRuntime();
@@ -100,7 +100,7 @@ void Q3DSRenderer::synchronize(QQuickFramebufferObject *inView)
m_initialized = false;
m_initializationFailure = false;
m_error.clear();
- static_cast<Q3DSView *>(inView)->setError(QString());
+ static_cast<Q3DSStudio3D *>(inView)->setError(QString());
}
m_initElements = false;
@@ -80,15 +80,15 @@ QOpenGLFramebufferObject *Q3DSRenderer::createFramebufferObject(const QSize &siz
* Invoked automatically by the QML scene graph.
*
- * This is the only place where it is valid for the Q3DSView plugin and render to communicate.
+ * This is the only place where it is valid for the Q3DSStudio3D plugin and render to communicate.
*/
void Q3DSRenderer::synchronize(QQuickFramebufferObject *inView)